@@ -1,11 +1,15 @@
+use std::time::{Duration, Instant};
+
+use ratatui::{
+    backend::Backend,
+    layout::{Alignment, Rect},
+    style::{Color, Modifier, Style},
+    terminal::Frame,
+    text::Span,
+    widgets::Paragraph,
+};
+
 use crate::display::{DisplayBandwidth, UIState};
-use ::std::time::{Duration, Instant};
-use ::tui::backend::Backend;
-use ::tui::layout::{Alignment, Rect};
-use ::tui::style::{Color, Modifier, Style};
-use ::tui::terminal::Frame;
-use ::tui::text::Span;
-use ::tui::widgets::Paragraph;
 
 const SECONDS_IN_DAY: u64 = 86400;
 
@@ -98,7 +102,7 @@ impl<'a> HeaderDetails<'a> {
         match self.elapsed_time.as_secs() / SECONDS_IN_DAY {
             0 => "".to_string(),
             1 => "1 day, ".to_string(),
-            n => format!("{} days, ", n),
+            n => format!("{n} days, "),
         }
     }
 
