@@ -9,6 +9,7 @@ use crossterm::event::{Event, KeyCode, KeyEvent, KeyModifiers};
 use packet_builder::*;
 use pnet::{datalink::DataLinkReceiver, packet::Packet};
 use pnet_base::MacAddr;
+use rstest::fixture;
 
 use crate::{
     network::dns::Client,
@@ -16,7 +17,7 @@ use crate::{
         create_fake_dns_client, get_interfaces, get_open_sockets, NetworkFrames, TerminalEvent,
         TerminalEvents, TestBackend,
     },
-    Opt, OsInputOutput, RenderOpts,
+    Opt, OsInputOutput,
 };
 
 pub fn sleep_and_quit_events(sleep_num: usize) -> Box<TerminalEvents> {
@@ -56,7 +57,8 @@ pub fn build_tcp_packet(
     pkt.packet().to_vec()
 }
 
-pub fn sample_frames() -> Vec<Box<dyn DataLinkReceiver>> {
+#[fixture]
+pub fn sample_frames_short() -> Vec<Box<dyn DataLinkReceiver>> {
     vec![NetworkFrames::new(vec![
         Some(build_tcp_packet(
             "10.0.0.2",
@@ -82,6 +84,125 @@ pub fn sample_frames() -> Vec<Box<dyn DataLinkReceiver>> {
     ]) as Box<dyn DataLinkReceiver>]
 }
 
+#[fixture]
+pub fn sample_frames_sustained_one_process() -> Vec<Box<dyn DataLinkReceiver>> {
+    vec![NetworkFrames::new(vec![
+        Some(build_tcp_packet(
+            "1.1.1.1",
+            "10.0.0.2",
+            12345,
+            443,
+            b"I have come from 1.1.1.1",
+        )),
+        None, // sleep
+        Some(build_tcp_packet(
+            "1.1.1.1",
+            "10.0.0.2",
+            12345,
+            443,
+            b"Same here, but one second later",
+        )),
+    ]) as Box<dyn DataLinkReceiver>]
+}
+
+#[fixture]
+pub fn sample_frames_sustained_multiple_processes() -> Vec<Box<dyn DataLinkReceiver>> {
+    vec![NetworkFrames::new(vec![
+        Some(build_tcp_packet(
+            "1.1.1.1",
+            "10.0.0.2",
+            12345,
+            443,
+            b"I have come from 1.1.1.1",
+        )),
+        Some(build_tcp_packet(
+            "3.3.3.3",
+            "10.0.0.2",
+            1337,
+            4435,
+            b"I come from 3.3.3.3",
+        )),
+        None, // sleep
+        Some(build_tcp_packet(
+            "1.1.1.1",
+            "10.0.0.2",
+            12345,
+            443,
+            b"I have come from 1.1.1.1 one second later",
+        )),
+        Some(build_tcp_packet(
+            "3.3.3.3",
+            "10.0.0.2",
+            1337,
+            4435,
+            b"I come 3.3.3.3 one second later",
+        )),
+    ]) as Box<dyn DataLinkReceiver>]
+}
+
+#[fixture]
+pub fn sample_frames_sustained_long() -> Vec<Box<dyn DataLinkReceiver>> {
+    vec![NetworkFrames::new(vec![
+        Some(build_tcp_packet(
+            "10.0.0.2",
+            "3.3.3.3",
+            4435,
+            1337,
+            b"omw to 3.3.3.3",
+        )),
+        Some(build_tcp_packet(
+            "3.3.3.3",
+            "10.0.0.2",
+            1337,
+            4435,
+            b"I was just there!",
+        )),
+        Some(build_tcp_packet(
+            "1.1.1.1",
+            "10.0.0.2",
+            12345,
+            443,
+            b"Is it nice there? I think 1.1.1.1 is dull",
+        )),
+        Some(build_tcp_packet(
+            "10.0.0.2",
+            "1.1.1.1",
+            443,
+            12345,
+            b"Well, I heard 1.1.1.1 is all the rage",
+        )),
+        None, // sleep
+        Some(build_tcp_packet(
+            "10.0.0.2",
+            "3.3.3.3",
+            4435,
+            1337,
+            b"Wait for me!",
+        )),
+        Some(build_tcp_packet(
+            "3.3.3.3",
+            "10.0.0.2",
+            1337,
+            4435,
+            b"They're waiting for you...",
+        )),
+        Some(build_tcp_packet(
+            "1.1.1.1",
+            "10.0.0.2",
+            12345,
+            443,
+            b"1.1.1.1 forever!",
+        )),
+        Some(build_tcp_packet(
+            "10.0.0.2",
+            "1.1.1.1",
+            443,
+            12345,
+            b"10.0.0.2 forever!",
+        )),
+    ]) as Box<dyn DataLinkReceiver>]
+}
+
 pub fn os_input_output(
     network_frames: Vec<Box<dyn DataLinkReceiver>>,
     sleep_num: usize,
@@ -147,28 +268,19 @@ pub fn os_input_output_factory(
 }
 
 pub fn opts_raw() -> Opt {
-    opts_factory(true)
-}
-
-pub fn opts_ui() -> Opt {
-    opts_factory(false)
-}
-
-fn opts_factory(raw: bool) -> Opt {
     Opt {
         interface: Some(String::from("interface_name")),
-        raw,
-        no_resolve: false,
-        show_dns: false,
-        dns_server: None,
-        render_opts: RenderOpts {
-            addresses: false,
-            connections: false,
-            processes: false,
-            total_utilization: false,
-        },
+        raw: true,
+        ..Default::default()
     }
 }
+pub fn opts_ui() -> Opt {
+    Opt {
+        interface: Some(String::from("interface_name")),
+        ..Default::default()
+    }
+}
+
 type BackendWithStreams = (
     Arc<Mutex<Vec<TerminalEvent>>>,
     Arc<Mutex<Vec<String>>>,
